<?php

namespace Blogtest\Blogtest\Policies;

use Litepie\User\Contracts\UserPolicy;
use Blogtest\Blogtest\Models\Articles;

class ArticlesPolicy
{

    /**
     * Determine if the given user can view the articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function view(UserPolicy $user, Articles $articles)
    {
        if ($user->canDo('blogtest.articles.view') && $user->isAdmin()) {
            return true;
        }

        return $articles->user_id == user_id() && $articles->user_type == user_type();
    }

    /**
     * Determine if the given user can create a articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blogtest.articles.create');
    }

    /**
     * Determine if the given user can update the given articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function update(UserPolicy $user, Articles $articles)
    {
        if ($user->canDo('blogtest.articles.edit') && $user->isAdmin()) {
            return true;
        }

        return $articles->user_id == user_id() && $articles->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Articles $articles)
    {
        return $articles->user_id == user_id() && $articles->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Articles $articles)
    {
        if ($user->canDo('blogtest.articles.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given articles.
     *
     * @param UserPolicy $user
     * @param Articles $articles
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Articles $articles)
    {
        if ($user->canDo('blogtest.articles.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
